{ config, pkgs, lib, ... }: {

  users.groups."syncthing".members = [ "mpd" "syncthing" "kodi" ];

  custom.samba-share = {
    enable = true;
    folders = {
      movies = config.services.syncthing.declarative.folders.movies.path;
      music = config.services.syncthing.declarative.folders.music-library.path;
      samples = config.services.syncthing.declarative.folders.samples.path;
      series = config.services.syncthing.declarative.folders.series.path;
      books = config.services.syncthing.declarative.folders.books.path;
    };
    #private.test = {
    #  folder = ;
    #  users = "kodi";
    #};
  };

  services.syncthing = {
    enable = true;
    openDefaultPorts = true;
    declarative = {
      cert = toString <secrets/syncthing/cert.pem>;
      key = toString <secrets/syncthing/key.pem>;

      overrideFolders = true;
      folders = {

        # on encrypted drive
        # ------------------
        private = {
          enable = true;
          path = "/home/syncthing/private";
        };
        desktop = {
          enable = true;
          path = "/home/syncthing/desktop";
        };
        finance = {
          enable = true;
          path = "/home/syncthing/finance";
        };
        lost-fotos = {
          enable = true;
          path = "/home/syncthing/lost-fotos.ct";
        };
        fotos = {
          enable = true;
          path = "/home/syncthing/fotos";
        };
        zettlr = {
          enable = true;
          path = "/home/syncthing/zettlr";
        };

        # no need to be encrypted
        # -----------------------
        books = {
          enable = true;
          path = "/media/syncthing/books";
          rescanInterval = 8 * 3600;
        };
        movies = {
          enable = true;
          path = "/media/syncthing/movies";
          rescanInterval = 8 * 3600;
        };
        music-projects = {
          enable = true;
          path = "/media/syncthing/music-projects";
        };
        music-library = {
          enable = true;
          path = "/media/syncthing/music-library";
          rescanInterval = 8 * 3600;
        };
        music-library-free = {
          enable = true;
          path = "/media/syncthing/music-library-free";
          rescanInterval = 8 * 3600;
        };
        samples = {
          enable = true;
          path = "/media/syncthing/samples";
          rescanInterval = 8 * 3600;
        };
        series = {
          enable = true;
          path = "/media/syncthing/series";
          rescanInterval = 8 * 3600;
        };
        smartphone-folder = {
          enable = true;
          path = "/media/syncthing/smartphone-folder";
          rescanInterval = 8 * 3600;
        };
        video-material = {
          enable = true;
          path = "/media/syncthing/video-material";
          rescanInterval = 8 * 3600;
        };
        processing = {
          enable = true;
          path = "/media/syncthing/sketchbook";
          rescanInterval = 8 * 3600;
        };

      };
    };
  };

  system.permown."/home/syncthing" = {
    owner = "syncthing";
    group = "syncthing";
  };
  system.permown."/media/syncthing" = {
    owner = "syncthing";
    group = "syncthing";
  };
  systemd.services."permown._media_syncthing" = {
    bindsTo = [ "media.mount" ];
    after = [ "media.mount" ];
  };
  systemd.services."syncthing" = {
    bindsTo = [ "media.mount" ];
    after = [ "media.mount" ];
  };

}
