{ config, pkgs, lib, ... }: {

  imports = [

    <system/desktop>
    ./hardware-configuration.nix

    ./packages.nix
    ./syncthing.nix
    ./tinc.nix

  ];

  networking.hostName = "sternchen";

  system.custom.mainUser.userName = "tina";

  system.custom.wifi.interfaces = [ "wlp3s0" ];

  security.wrappers = {
    pmount.source = "${pkgs.pmount}/bin/pmount";
    pumount.source = "${pkgs.pmount}/bin/pumount";
  };

  programs.custom.steam.enable = false;
  programs.custom.video.enable = true;

  # keyboard fiddling
  i18n.defaultLocale = "de_DE.UTF-8";
  console.keyMap = "de";
  services.xserver.layout = "de,us";

  system.custom.suspend.enable = false;
  services.printing.enable = true;

  # fonts
  # -----
  programs.custom.urxvt.fontSize = 12;
  programs.custom.xterm.fontSize = 12;
  system.custom.fonts.dpi = 100;

  # x11
  # ---
  configuration.desktop = {
    width = 1366;
    height = 768;
  };
  # for congress and streaming
  hardware.opengl = {
    enable = true;
    extraPackages = [ pkgs.vaapiIntel ];
    driSupport = true;
    driSupport32Bit = true;
  };
  nixpkgs.config.packageOverrides = pkgs: {
    vaapiIntel = pkgs.vaapiIntel.override { enableHybridCodec = true; };
  };

  services.xserver.displayManager.defaultSession = "plasma5";
  services.xserver.desktopManager.pantheon.enable = true;
  services.xserver.desktopManager.plasma5.enable = true;
  services.xserver.desktopManager.xfce.enable = true;
  services.xserver.desktopManager.gnome3.enable = false;

  # stuff
  # -----
  custom.samba-share = {
    enable = false;
    folders = {
      #public = "/home/palo/movies";
      share = "/home/share";
      #syncthing = "/mnt/syncthing";
      #movies = "/mnt/syncthing/movies";
      #series = "/mnt/syncthing/series";
    };
  };

  # enable this to use sidequest
  programs.adb.enable = false;
  users.users.mainUser.extraGroups = [ "adbusers" "video" ];

  virtualisation = {
    docker.enable = false;

    virtualbox = {
      host.enable = false;
      guest.x11 = false;
      guest.enable = false;
    };
  };

  # keybase
  services.keybase.enable = false;
  services.kbfs.enable = false;

}

